@@ -8,27 +8,27 @@ sub init {
     my $class = caller(0);
 
     eval "require AI::MicroStructure::$alias;";
-    croak "Aliased theme AI::MicroStructure::$alias failed to load: $@"
+    croak "Aliased structure AI::MicroStructure::$alias failed to load: $@"
         if $@;
 
     no strict 'refs';
     no warnings;
 
     # copy almost everything over from the original
-    for my $k ( grep { ! /^(?:Theme|micro|import)$/ }
+    for my $k ( grep { ! /^(?:structure|micro|import)$/ }
         keys %{"AI::MicroStructure::$alias\::"} )
     {
         *{"$class\::$k"} = *{"AI::MicroStructure::$alias\::$k"};
     }
 
     # local things
-    ${"$class\::Theme"} = ( split /::/, $class )[-1];
+    ${"$class\::structure"} = ( split /::/, $class )[-1];
     ${"$class\::micro"}  = $class->new();
     *{"$class\::import"} = sub {
         my $callpkg = caller(0);
-        my $theme   = ${"$class\::Theme"};
+        my $structure   = ${"$class\::structure"};
         my $micro    = $class->new();
-        *{"$callpkg\::micro$theme"} = sub { $micro->name(@_) };
+        *{"$callpkg\::micro$structure"} = sub { $micro->name(@_) };
       };
 }
 
