@@ -1,7 +1,7 @@
 package AI::MicroStructure::Locale;
 use strict;
 use warnings;
-use AI::MicroStructure (); # do not export metaname and friends
+use AI::MicroStructure (); # do not export microname and friends
 use AI::MicroStructure::MultiList;
 use List::Util qw( shuffle );
 use Carp;
@@ -31,8 +31,8 @@ sub new {
             ? $self->{lang}
             : $ENV{LANGUAGE} || $ENV{LANG} || '';
         if( !$self->{category} && $^O eq 'MSWin32' ) {
-            eval { require Win32::Locale; };
-            $self->{category} = Win32::Locale::get_language() unless $@;
+            #eval { require Win32::Locale; };
+            #$self->{category} = Win32::Locale::get_language() unless $@;
         }
     }
 
